@@ -4,20 +4,24 @@ A minimalist Python library providing basic utility functions
 for common operations like printing messages and arithmetic.
 
 Author: fjmpereira20
-Version: 1.0.0
+Version: 1.6.0
 """
 
 from .core import (
     add_numbers,
     divide_numbers,
+    format_currency,
+    is_even,
+    max_numbers,
+    min_numbers,
     multiply_numbers,
     print_message,
     square_numbers,
 )
 
-__version__ = "1.3.0"
+__version__ = "1.6.0"
 __author__ = "fjmpereira20"
-__email__ = "your.email@example.com"  # Replace with actual email
+__email__ = "fjmpereira20@users.noreply.github.com"
 
 __all__ = [
     "print_message",
@@ -25,4 +29,8 @@ __all__ = [
     "multiply_numbers",
     "divide_numbers",
     "square_numbers",
+    "max_numbers",
+    "min_numbers",
+    "is_even",
+    "format_currency",
 ]
